@@ -5,4 +5,5 @@ except ImportError:
 
 from .device import to_device, to_device_enumrate, construct_device_args_kwargs
 from .keys import K
-from . import safe_io
+from .filebranch import FileBranch
+from .safe_io import IO
\ No newline at end of file
